# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2025-06-20)

### Fix

* More configuration for ewok.App ([`fb9e5c3`](https://github.com/educationwarehouse/ewok/commit/fb9e5c35329fa9c20aeda598bac9dea0bc430c4c))

## v0.1.0 (2025-06-20)

### Feature

* Initial project setup ([`3049a47`](https://github.com/educationwarehouse/ewok/commit/3049a4784e1abf659ccfb098493282a0c62f535e))
